%% Section 1

clearvars; 
close all; 
clc;

%% Section 2 - loading data
load venice_hourly

% as a result of the above command variables time_ve_all and sl_ve_all are
% loaded into workspace
% time_ve_all contains time of sea level measurements in a form of: 
% column 1 - year; column 2 - month; column 3 - day; column 4 - hour;
% column 5 - minute; column 6 - second 
% sl_ve_all contains various components of sea level measurements 
% column 1 - original measurements; column 2 - tidal signal; 
% column 3 - residual; column 4 - trend


%% Section 3 - plot original data 
% command datenum transfers time into MATLAB format 
time_ve = datenum(time_ve_all); 

figure(1)
% 1st plot original data 
plot(time_ve,sl_ve_all(:,1),'k-')
grid on
xlabel('Year')
ylabel('Sea level height (cm)')
title('Venice')

% add date ticks on x-axis
datetick 

%% plot tidal oscillations over original data
figure(1)
hold on
% command for keeping old plot (original sea level time series) on 
plot(time_ve,sl_ve_all(:,2),'r-')


%% plot residual (original sea level - tidal signal) over original data
plot(time_ve,sl_ve_all(:,3),'b-')

%% plot trend over original data
plot(time_ve,sl_ve_all(:,4),'g-','LineWidth',2)

% add legend so that we know what is each line
legend('Original','Tidal','Residual','Trend')